from adlfs import AzureBlobFileSystem as _AzureBlobFileSystem


class AzureBlobFileSystem(  # pylint: disable=abstract-method
    _AzureBlobFileSystem
):
    def put_file(self, *args, **kwargs) -> None:
        kwargs["overwrite"] = True
        return super().put_file(*args, **kwargs)

    async def _put_file(self, *args, **kwargs) -> None:
        kwargs["overwrite"] = True
        return await super()._put_file(*args, **kwargs)

    def rm(self, *args, **kwargs) -> None:
        kwargs["expand_path"] = False
        return super().rm(*args, **kwargs)

    async def _rm(self, *args, **kwargs) -> None:
        kwargs["expand_path"] = False
        return await super()._rm(*args, **kwargs)



import os

# pylint: disable=redefined-outer-name
import pytest

from .cloud import Azure


@pytest.fixture
def make_azure(request):
    def _make_azure():
        if os.environ.get("DVC_TEST_AZURE_PATH"):
            path = Azure.get_storagepath()
        else:
            path = None
        connection_string = os.environ.get("DVC_TEST_AZURE_CONNECTION_STRING")
        if not (path and connection_string):
            path = request.getfixturevalue("tmp_azure_path")
            connection_string = request.getfixturevalue("azurite")
        return Azure(
            str(path).replace("az://", "azure://"),
            connection_string=connection_string,
        )

    return _make_azure


@pytest.fixture
def azure(make_azure):
    return make_azure()



import pytest
from dvc.testing.api_tests import (  # noqa, pylint: disable=unused-import
    TestAPI,
)
from dvc.testing.remote_tests import (  # noqa, pylint: disable=unused-import
    TestRemote,
)
from dvc.testing.workspace_tests import (  # noqa, pylint: disable=unused-import
    TestGetUrl,
)
from dvc.testing.workspace_tests import TestImport as _TestImport
from dvc.testing.workspace_tests import (  # noqa, pylint: disable=unused-import
    TestLsUrl,
)


@pytest.fixture
def cloud(make_cloud):
    yield make_cloud(typ="azure")


@pytest.fixture
def remote(make_remote):
    yield make_remote(name="upstream", typ="azure")


@pytest.fixture
def workspace(make_workspace):
    yield make_workspace(name="workspace", typ="azure")


@pytest.mark.xfail(
    reason="waiting for https://github.com/fsspec/adlfs/pull/333"
)
class TestImport(_TestImport):
    @pytest.fixture
    def stage_md5(self):
        return "ffe462bbb08432b7a1c3985fcf82ad3a"

    @pytest.fixture
    def is_object_storage(self):
        return True

    @pytest.fixture
    def dir_md5(self):
        return "ec602a6ba97b2dd07bd6d2cd89674a60.dir"
